#!/usr/bin/perl
# Author: I.Plisco
# Aim: Makes TXT files from HTML ones for bartleby.com ethymology data.
#
# Also makes index for text files (index.html).

use File::Find;
#use Data::Dumper;

# Define parameters
$dir_in = 'h:\mirrors\www.bartleby.com\61\roots';
$/ = undef;

my(%index);

# Test or work
if(0) {
  chdir $dir_in;
  procede('IE15.html');
  procede('IE158.html');
} else {
  find(\&procede, $dir_in);
}

$index = join('', map {$index{$_}} sort {$a <=> $b} keys %index);

# Make index.html
open(INDEX, ">$dir_in\\index.html");
print INDEX <<EOF;
<html>
<head>
<title>Indo-European Roots Index</title>
</head>
<body>
<h1>Indo-European Roots Index</h1>
<P>
$index
<P>
<HR>
<P>
Thanks to <a href=http://www.bartleby.com>www.bartleby.com</a>
<P>
</body>
</html>
EOF

close (INDEX);

exit;

#============================================================
sub procede {
#============================================================
# Procedes one file.
#
# Parameters:
# 1 - file name (optional)
# 
# Returns: 1 on OK, false - otherwise.
#------------------------------------------------------------
  my($file) = @_;
  my($outfile);

  $file |= $File::Find::name;
  return unless $file;
  return if($file =~ /index\.html/);

  print "Processing $file...\n";

  ($outfile = $file) =~ s/html$/txt/;
  return if($file eq $outfile);	# Don't overwrite it

# Read file
  open(IN, $file) || return;
  $data = <IN>;
  close IN;

# Make substitutions
  $data =~ s/^.*ENTRY/ENTRY/s;	# header
  $data =~ s/\n\n.*/\n/s;	# footer
  $data =~ s/\<A HREF[^>]+\>/{/gs;	# links
  $data =~ s/\{(\w+)/\{\1\}/gs;
  $data =~ s/\<IMG[^>]*\/(\w+)\.gif/\[\1\]\</gs;	# letters as images
  $data =~ s/\<BR\>/\n/g;	# <BR> to CR
  $data =~ s/\<[^>]*\>//gs;	# remove HTML tags
  $data =~ s/\&nbsp\;?/ /g;	# nbsp to spaces

# Write it
  open(OUT, ">$outfile") || return;
  print OUT $data;
  close OUT;

# Add entry to index
  $outfile =~ s/.*[\\\/]//;
  $data =~ /^ENTRY:(.*)\n/;
  $entry = $1;
  $outfile =~ /(\d+)/;
  $num = $1;
  $index{$num} = "<a href=$outfile>$entry</a><BR>\n";

}
